==> topia-persistence-2.5-test-sources.jar: org/nuiton/topiatest/deletetest/Contact2Abstract.java <==
package org.nuiton.topiatest.deletetest;

import java.util.ArrayList;
import java.util.Collection;
import java.util.List;
import org.apache.commons.lang.builder.ToStringBuilder;
import org.nuiton.i18n.I18n;
import org.nuiton.topia.TopiaException;
import org.nuiton.topia.persistence.EntityVisitor;
import org.nuiton.topia.persistence.TopiaEntity;
import org.nuiton.topia.persistence.TopiaEntityAbstract;
import org.nuiton.topia.persistence.util.TopiaEntityHelper;


public  abstract class Contact2Abstract extends TopiaEntityAbstract implements Contact2 {

    /**
     * Nom de l'attribut en BD : contactValue

     */
    protected String contactValue;
    /**
     * Nom de l'attribut en BD : type

     */
    protected String type;
    /**
     * Nom de l'attribut en BD : party2

     */
    protected Collection<Party2> party2;
static {
    
        I18n.n_("topia.test.common.contact2");
        I18n.n_("topia.test.common.contactValue");
        I18n.n_("topia.test.common.type");
        I18n.n_("topia.test.common.party2");
    }
    /**
     * accept :
     * Envoi via les methodes du visitor l'ensemble des champs de l'entity
avec leur nom, type et valeur.
     * @param visitor le visiteur de l'entite.
     * @throws TopiaException
     */

    public void accept(EntityVisitor visitor) throws TopiaException {
        visitor.start(this);
        visitor.visit(this, PROPERTY_CONTACT_VALUE, String.class, contactValue);
        visitor.visit(this, PROPERTY_TYPE, String.class, type);
        visitor.visit(this, PROPERTY_PARTY2, Collection.class, Party2.class, party2);
        visitor.end(this);
}

    /**
     * setContactValue :
     * @param contactValue 
     */

    @Override
    public void setContactValue(String contactValue) {
        String oldValue = this.contactValue;
        fireOnPreWrite(PROPERTY_CONTACT_VALUE, oldValue, contactValue);
        this.contactValue = contactValue;
        fireOnPostWrite(PROPERTY_CONTACT_VALUE, oldValue, contactValue);
}

    /**
     * getContactValue :
     * @return String 
     */

    @Override
    public String getContactValue() {
        fireOnPreRead(PROPERTY_CONTACT_VALUE, contactValue);
        String result = this.contactValue;
        fireOnPostRead(PROPERTY_CONTACT_VALUE, contactValue);
        return result;
}

    /**
     * setType :
     * @param type 
     */

    @Override
    public void setType(String type) {
        String oldValue = this.type;
        fireOnPreWrite(PROPERTY_TYPE, oldValue, type);
        this.type = type;
        fireOnPostWrite(PROPERTY_TYPE, oldValue, type);
}

    /**
     * getType :
     * @return String 
     */

    @Override
    public String getType() {
        fireOnPreRead(PROPERTY_TYPE, type);
        String result = this.type;
        fireOnPostRead(PROPERTY_TYPE, type);
        return result;
}

    /**
     * addParty2 :
     * @param party2 
     */

    @Override
    public void addParty2(Party2 party2) {
        fireOnPreWrite(PROPERTY_PARTY2, null, party2);
        if (this.party2 == null) {
            this.party2 = new ArrayList<Party2>();
        }

        if (party2.getContacts() == null) {
            party2.setContacts(new ArrayList<Contact2>());
        }
        party2.getContacts().add(this);

        this.party2.add(party2);
        fireOnPostWrite(PROPERTY_PARTY2, this.party2.size(), null, party2);
}

    /**
     * addAllParty2 :
     * @param party2 
     */

    @Override
    public void addAllParty2(Collection<Party2> party2) {
        if (party2 == null) {
            return;
        }
        for (Party2 item : party2) {
            addParty2(item);
        }
}

    /**
     * setParty2 :
     * @param party2 
     */

    @Override
    public void setParty2(Collection<Party2> party2) {
        // Copy elements to keep data for fire with new reference
        Collection<Party2> oldValue = this.party2 != null ? new ArrayList<Party2>(this.party2) : null;
        fireOnPreWrite(PROPERTY_PARTY2, oldValue, party2);
        this.party2 = party2;
        fireOnPostWrite(PROPERTY_PARTY2, oldValue, party2);
}

    /**
     * removeParty2 :
     * @param party2 
     */

    @Override
    public void removeParty2(Party2 party2) {
        fireOnPreWrite(PROPERTY_PARTY2, party2, null);
        if ((this.party2 == null) || (!this.party2.remove(party2))) {
            throw new IllegalArgumentException("List does not contain given element");
        }

        party2.getContacts().remove(this);

        fireOnPostWrite(PROPERTY_PARTY2, this.party2.size() + 1, party2, null);
}

    /**
     * clearParty2 :
     */

    @Override
    public void clearParty2() {
        if (this.party2 == null) {
            return;
        }
        for (Party2 item : this.party2) {
            item.getContacts().remove(this);
        }
        Collection<Party2> oldValue = new ArrayList<Party2>(this.party2);
        fireOnPreWrite(PROPERTY_PARTY2, oldValue, this.party2);
        this.party2.clear();
        fireOnPostWrite(PROPERTY_PARTY2, oldValue, this.party2);
}

    /**
     * getParty2 :
     * @return Collection<Party2> 
     */

    @Override
    public Collection<Party2> getParty2() {
        return party2;
}

    /**
     * getParty2ByTopiaId :
     * @param topiaId 
     * @return Party2 
     */

    @Override
    public Party2 getParty2ByTopiaId(String topiaId) {
        return TopiaEntityHelper.getEntityByTopiaId(party2, topiaId);
 }

    /**
     * sizeParty2 :
     * @return int 
     */

    @Override
    public int sizeParty2() {
        if (party2 == null) {
            return 0;
        }
        return party2.size();
}

    /**
     * isParty2Empty :
     * @return boolean 
     */

    @Override
    public boolean isParty2Empty() {
        int size = sizeParty2();
        return size == 0;
}

    /**
     * getAggregate :
     * @return List<TopiaEntity> 
     * @throws TopiaException
     */

    @Override
    public List<TopiaEntity> getAggregate() throws TopiaException {
        List<TopiaEntity> tmp = new ArrayList<TopiaEntity>();

        // pour tous les attributs rechecher les composites et les class d'asso
        // on les ajoute dans tmp

        // on refait un tour sur chaque entity de tmp pour recuperer leur
        // composite
        List<TopiaEntity> result = new ArrayList<TopiaEntity>();
        for (TopiaEntity entity : tmp) {
            result.add(entity);
            result.addAll(entity.getAggregate());
        }

        return result;
}

    /**
     * getComposite :
     * @return List<TopiaEntity> 
     * @throws TopiaException
     */

    @Override
    public List<TopiaEntity> getComposite() throws TopiaException {
        List<TopiaEntity> tmp = new ArrayList<TopiaEntity>();

        // pour tous les attributs rechecher les composites et les class d'asso
        // on les ajoute dans tmp

        // on refait un tour sur chaque entity de tmp pour recuperer leur
        // composite
        List<TopiaEntity> result = new ArrayList<TopiaEntity>();
        for (TopiaEntity entity : tmp) {
            if (entity != null) {
                result.add(entity);
                result.addAll(entity.getComposite());
            }
        }

        return result;
    }

    /**
     * toString :
     * @return String 
     */

    @Override
    public String toString() {
        String result = new ToStringBuilder(this).
            append(PROPERTY_CONTACT_VALUE, this.contactValue).
            append(PROPERTY_TYPE, this.type).
         toString();
        return result;
}


} //Contact2Abstract

==> topia-persistence-2.6.2-test-sources.jar: org/nuiton/topiatest/deletetest/Contact2Abstract.java <==
package org.nuiton.topiatest.deletetest;

import java.util.ArrayList;
import java.util.Collection;
import java.util.List;
import org.apache.commons.lang.builder.ToStringBuilder;
import org.nuiton.i18n.I18n;
import org.nuiton.topia.TopiaException;
import org.nuiton.topia.persistence.EntityVisitor;
import org.nuiton.topia.persistence.TopiaEntity;
import org.nuiton.topia.persistence.TopiaEntityAbstract;
import org.nuiton.topia.persistence.util.TopiaEntityHelper;

public  abstract class Contact2Abstract extends TopiaEntityAbstract implements Contact2 {

    /**
     * Nom de l'attribut en BD : contactValue

     */
    protected String contactValue;
    /**
     * Nom de l'attribut en BD : type

     */
    protected String type;
    /**
     * Nom de l'attribut en BD : party2

     */
    protected Collection<Party2> party2;
    private static final long serialVersionUID = 7148679594314643812L;

static {
    
        I18n.n_("topia.test.common.contact2");
        I18n.n_("topia.test.common.contactValue");
        I18n.n_("topia.test.common.type");
        I18n.n_("topia.test.common.party2");
    }
     /**
      * accept :
      * Envoi via les methodes du visitor l'ensemble des champs de l'entity
avec leur nom, type et valeur.
      * @param visitor le visiteur de l'entite.
      * @throws TopiaException
      */
    public void accept(EntityVisitor visitor) throws TopiaException {
        visitor.start(this);
        visitor.visit(this, PROPERTY_CONTACT_VALUE, String.class, contactValue);
        visitor.visit(this, PROPERTY_TYPE, String.class, type);
        visitor.visit(this, PROPERTY_PARTY2, Collection.class, Party2.class, party2);
        visitor.end(this);
}

     /**
      * setContactValue :
      * @param contactValue 
      */

    @Override    public void setContactValue(String contactValue) {
        String oldValue = this.contactValue;
        fireOnPreWrite(PROPERTY_CONTACT_VALUE, oldValue, contactValue);
        this.contactValue = contactValue;
        fireOnPostWrite(PROPERTY_CONTACT_VALUE, oldValue, contactValue);
}

     /**
      * getContactValue :
      * @return String 
      */

    @Override    public String getContactValue() {
        fireOnPreRead(PROPERTY_CONTACT_VALUE, contactValue);
        String result = this.contactValue;
        fireOnPostRead(PROPERTY_CONTACT_VALUE, contactValue);
        return result;
}

     /**
      * setType :
      * @param type 
      */

    @Override    public void setType(String type) {
        String oldValue = this.type;
        fireOnPreWrite(PROPERTY_TYPE, oldValue, type);
        this.type = type;
        fireOnPostWrite(PROPERTY_TYPE, oldValue, type);
}

     /**
      * getType :
      * @return String 
      */

    @Override    public String getType() {
        fireOnPreRead(PROPERTY_TYPE, type);
        String result = this.type;
        fireOnPostRead(PROPERTY_TYPE, type);
        return result;
}

     /**
      * addParty2 :
      * @param party2 
      */

    @Override    public void addParty2(Party2 party2) {
        fireOnPreWrite(PROPERTY_PARTY2, null, party2);
        if (this.party2 == null) {
            this.party2 = new ArrayList<Party2>();
        }

        if (party2.getContacts() == null) {
            party2.setContacts(new ArrayList<Contact2>());
        }
        party2.getContacts().add(this);

        this.party2.add(party2);
        fireOnPostWrite(PROPERTY_PARTY2, this.party2.size(), null, party2);
}

     /**
      * addAllParty2 :
      * @param party2 
      */

    @Override    public void addAllParty2(Collection<Party2> party2) {
        if (party2 == null) {
            return;
        }
        for (Party2 item : party2) {
            addParty2(item);
        }
}

     /**
      * setParty2 :
      * @param party2 
      */

    @Override    public void setParty2(Collection<Party2> party2) {
        // Copy elements to keep data for fire with new reference
        Collection<Party2> oldValue = this.party2 != null ? new ArrayList<Party2>(this.party2) : null;
        fireOnPreWrite(PROPERTY_PARTY2, oldValue, party2);
        this.party2 = party2;
        fireOnPostWrite(PROPERTY_PARTY2, oldValue, party2);
}

     /**
      * removeParty2 :
      * @param party2 
      */

    @Override    public void removeParty2(Party2 party2) {
        fireOnPreWrite(PROPERTY_PARTY2, party2, null);
        if ((this.party2 == null) || (!this.party2.remove(party2))) {
            throw new IllegalArgumentException("List does not contain given element");
        }

        party2.getContacts().remove(this);

        fireOnPostWrite(PROPERTY_PARTY2, this.party2.size() + 1, party2, null);
}

     /**
      * clearParty2 :
      */

    @Override    public void clearParty2() {
        if (this.party2 == null) {
            return;
        }
        for (Party2 item : this.party2) {
            item.getContacts().remove(this);
        }
        Collection<Party2> oldValue = new ArrayList<Party2>(this.party2);
        fireOnPreWrite(PROPERTY_PARTY2, oldValue, this.party2);
        this.party2.clear();
        fireOnPostWrite(PROPERTY_PARTY2, oldValue, this.party2);
}

     /**
      * getParty2 :
      * @return Collection<Party2> 
      */

    @Override    public Collection<Party2> getParty2() {
        return party2;
}

     /**
      * getParty2ByTopiaId :
      * @param topiaId 
      * @return Party2 
      */

    @Override    public Party2 getParty2ByTopiaId(String topiaId) {
        return TopiaEntityHelper.getEntityByTopiaId(party2, topiaId);
 }

     /**
      * sizeParty2 :
      * @return int 
      */

    @Override    public int sizeParty2() {
        if (party2 == null) {
            return 0;
        }
        return party2.size();
}

     /**
      * isParty2Empty :
      * @return boolean 
      */

    @Override    public boolean isParty2Empty() {
        int size = sizeParty2();
        return size == 0;
}

     /**
      * getAggregate :
      * @return List<TopiaEntity> 
      * @throws TopiaException
      */

    @Override    public List<TopiaEntity> getAggregate() throws TopiaException {
        List<TopiaEntity> tmp = new ArrayList<TopiaEntity>();

        // pour tous les attributs rechecher les composites et les class d'asso
        // on les ajoute dans tmp

        // on refait un tour sur chaque entity de tmp pour recuperer leur
        // composite
        List<TopiaEntity> result = new ArrayList<TopiaEntity>();
        for (TopiaEntity entity : tmp) {
            result.add(entity);
            result.addAll(entity.getAggregate());
        }

        return result;
}

     /**
      * getComposite :
      * @return List<TopiaEntity> 
      * @throws TopiaException
      */

    @Override    public List<TopiaEntity> getComposite() throws TopiaException {
        List<TopiaEntity> tmp = new ArrayList<TopiaEntity>();

        // pour tous les attributs rechecher les composites et les class d'asso
        // on les ajoute dans tmp

        // on refait un tour sur chaque entity de tmp pour recuperer leur
        // composite
        List<TopiaEntity> result = new ArrayList<TopiaEntity>();
        for (TopiaEntity entity : tmp) {
            if (entity != null) {
                result.add(entity);
                result.addAll(entity.getComposite());
            }
        }

        return result;
    }

     /**
      * toString :
      * @return String 
      */

    @Override    public String toString() {
        String result = new ToStringBuilder(this).
            append(PROPERTY_CONTACT_VALUE, this.contactValue).
            append(PROPERTY_TYPE, this.type).
         toString();
        return result;
}


} //Contact2Abstract
